# zenberry

`zenberry` is a Python library that acts like `time.sleep` but beeps gently every second ^_^

Tested on macOS

## Installation

```bash
pip install zenberry
```

## Usage

```bash
import zenberry
zenberry.sleep(42)
#beeps 42 times
```
